import serial

from ..base import LedControlDevice

class LEDD1B(LedControlDevice):
    """
    Control a Thorlabs LEDD1B LED driver using an Arduino Nano.
    The arduino must have the correct software loaded on it.
    (See `arduino-thorlabs-ledd1b`project directory.)

    Note: This currently has COM4 hardcoded
    """
    def __init__(self, port="COM4"):    
        self.arduino = serial.Serial(port=port, baudrate=9600, timeout=.1)
        # self._check_arduino_software()
        
    def __del__(self):
        self.arduino.close()
    
    def _check_arduino_software(self):
        """
        Run the identify command and raise an Exception
        if the Arduino does not reply with the expected output.
        """
        self._write('i')
        lines = self.read()
        if len(lines) < 1 or not lines[-1].startswith(bytes("Arduino Nano CPD 1", "utf-8")):
            print(lines)
            raise Exception("Arduino did not return the expected output - does it have the correct software loaded?")

    def _write(self, val):
        self.arduino.write(bytes(val, 'utf-8')) 
        
    def read(self):
        data = self.arduino.readlines()
        return data
       
    def on(self):
        self._write("1")
    def off(self):
        self._write("0")
    def set_level(self, level:int):
        if level == 0: self.off()
        elif level == 100: self.on()
        else:
            raise ValueError(f"LEDD1B Led controller can only set 0% or 100%")

    def __str__(self):
        return "Thorlabs LEDD1B"

   
if __name__ == '__main__':
    led = LEDD1B()