import matplotlib.pyplot as plt
import numpy as np

def _update_print(i, tval, vval):
    print(f"n = {i:5d}, t = {tval: .2f} s, U = {vval: .5f} V" + " "*10, end='\r')

class _Monitor:
    """
    Monitor v and i data in a matplotlib window
    """
    def __init__(self, led_data=True, max_points_shown=None, use_print=False):
        self.max_points_shown = max_points_shown
        self.use_print = use_print
        self.index = []
        self.vdata = []
        self.tdata = []
        self.ldata = []

        plt.ion()
        self.fig1, self.vax = plt.subplots(1, 1, figsize=(8, 5))
        self.led_data = led_data
        if self.led_data:
            self.lax = self.vax.twinx()
            self.lax.set_ylabel("LED [%]")
            self.lline, = self.lax.plot(self.tdata, self.ldata, color="orange")
            self.lax.set_ylim(-0.5, 100.5)
        self.vline, = self.vax.plot(self.tdata, self.vdata, color="blue")
        self.vax.set_xlabel("time [s]")
        self.vax.set_ylabel("Voltage [V]")
        self.vax.grid(True)


    def update(self, i, tval, vval, led_val=-1):
        if self.use_print:
            _update_print(i, tval, vval)
        self.index.append(i)
        self.tdata.append(tval)
        self.vdata.append(vval)
        if self.led_data:
            self.ldata.append(led_val)
            self.lline.set_xdata(self.tdata)
            self.lline.set_ydata(self.ldata)
        # update data
        self.vline.set_xdata(self.tdata)
        self.vline.set_ydata(self.vdata)
        # recalculate limits and set them for the view
        self.vax.relim()
        if self.max_points_shown and i > self.max_points_shown:
            self.vax.set_xlim(self.tdata[i-self.max_points_shown], self.tdata[i])
        self.vax.autoscale_view()
        # update plot
        self.fig1.canvas.draw()
        self.fig1.canvas.flush_events()

    def __del__(self):
        plt.close(self.fig1)
